#
# spec file for package product-composer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if "%{?sle_version}" == "150600"
%define used_python python311
%else
%define used_python python3
%endif

Name:           product-composer
Version:        0.6.10
Release:        1.1
Summary:        Product Composer
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/openSUSE/product-composer
#!CreateArchive: product-composer
Source:         %name-%{version}.tar.xz
# Should become a build option
Patch10:        sle-15-defaults.patch
BuildRequires:  %{used_python}-pip
BuildRequires:  %{used_python}-poetry-core
BuildRequires:  %{used_python}-setuptools
BuildRequires:  %{used_python}-setuptools_scm
BuildRequires:  %{used_python}-wheel
Requires:       %{used_python}-PyYAML
Requires:       %{used_python}-pydantic
Requires:       %{used_python}-rpm
Requires:       %{used_python}-zstandard
# build for signdummy
Requires:       build
Requires:       checkmedia
Requires:       createrepo_c
Requires:       inst-source-utils
Requires:       libsolv-tools
Requires:       mkisofs
Requires:       mksusecd >= 3.5
BuildArch:      noarch

%description
The new product builder for ALP family and beyond.
WARNING: please be aware that the code is still on the move and is
         likely to break with productcompose file syntax changes.

%prep
%setup -q -n %name-%version
%if "%{?sle_version}" == "150600"
%patch -P 10 -p1
%endif

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%version
%if "%{?sle_version}" == "150600"
%python311_pyproject_wheel
%else
%python3_pyproject_wheel
%endif

%install
%if "%{?sle_version}" == "150600"
%python311_pyproject_install
%else
%python3_pyproject_install
%endif
mv %buildroot/usr/bin/productcomposer %buildroot%_bindir/product-composer

%files
%doc README.rst docs examples
%_bindir/product-composer
%if "%{?sle_version}" == "150600"
%{python311_sitelib}/*
%else
%{python3_sitelib}/*
%endif

%changelog
* Tue Jul 22 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.10:
  * fixing missing debuginfo package in case dwz compression
    mechanic is used.
* Fri Jul 11 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.9:
  * Create the .license directory independend of iso generation
  * Support set_updateinfo_id_prefix to be set per flavor
* Mon Jul  7 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.8:
  * One more attempt for crashes in iso handling
  * Accept product_name_prefix key in scc block
* Fri Jul  4 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.7:
  * Make the diskusage estimation compatible to the old implementation.
    Doing the kb conversation by file to cover fs block size
  * Implement option to follow package version for product
* Fri Jul  4 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.6
  * verify command works now also for setups which only builds
    via a flavor
  * Export directory content sizes in kb (boo#1245709)
* Thu Jul  3 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.5
  * Fixing further regressions of refactoring for iso building
* Thu Jul  3 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.4
  * Fixing the iso parsing crash for real
* Mon Jun 30 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.3
  * include last two patches, obsoleting
  - change-fitering-error-to-warning.patch
  - parse-supportstatus.patch
  * fixing a crash when iso's are only enabled in flavors
- fix build/version handling after the change to setuptools_scm
* Wed Jun 25 2025 Dirk Müller <dmueller@suse.com>
- add change-fitering-error-to-warning.patch:
  * Change updateinfo filtering error to a warning
* Tue Jun 24 2025 Dirk Müller <dmueller@suse.com>
- add parse-supportstatus.patch:
  * fixes crash on parsing supportstatus information
* Wed Jun  4 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.2
  * crash fix for agama builds
  * Rework package set calculation
    The new code allows to reference package sets that are defined
    later in the recipe. It also allows to specify a flavor or
    architecture in the reference, so that a flavor can reuse the
    package set of a different flavor.
* Wed Jun  4 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.1:
  * fixing a crash when no 'iso' tag is defined
* Mon Jun  2 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.6.0:
  * obsolete schema dependency again and rely on pydantic
  * support AppStream generation
  * support packageset selections in flavors via content and unpack
  * allow overwrite of supportstatus via = prefix
  * larger code refactoring for first unit tests
* Wed May 21 2025 Adrian Schröter <adrian@suse.de>
- add missing dependency to python schema module
* Fri May 16 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.16:
  * package EULA support added
  * agama: do not take the iso meta data from the agama iso
  * code cleanup and refactoring
  * build description files are now validated.
  * verify command is now checking all flavors by default.
* Tue May 13 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.15:
  * fix generation of gpg-pubkey content tags
  * Do not error out in updateinfo_packages_only mode if packages are not found
  * Set BUILD_DIR before calling the sbom generator
  * Handle build_options in flavors different
    Add them to the global set, instead of replacing the global set.
  * Fix handover of multiple --build-option cli parameters
* Mon May 12 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.14:
  * fixing CPE-ID generation (ommit * in empty fields)
  * allowing to select build-options via cli and project build configuration
* Wed Apr 30 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.13:
  * support encoding of "update" and "edition" fields into CPE
  * allow blacklisting binaries via updateinfo flag
  * allow to specify repodata config per flavor
* Mon Mar 31 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.12:
  * Fix handling of internal updateinfo.xml attributes
    supportstatus, superseded_by and embargo_date .
* Fri Mar 21 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.11
  * cli: keep creating Source and Debug images when using the baseiso feature
  * fix crash on missing summary field
* Fri Feb 28 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.10
  * allow to specify build_options per flavor
  * build_option for skiping copy of rpm-md trees to base iso
  * build_option for updateinfo_packages_only
  * bugfixes and cleanup
* Tue Feb 25 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.9
  Crash fix for offline media build using splitted repodata
* Mon Feb 24 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.8
  Added missing bits for splitted source medium
* Fri Feb 21 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.7
  Fixing splitted repodata handling with splitted source medium
* Thu Feb 20 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.6
  Call verifymedia on generated bootable media for verbose output
  in log file. It is not fatal yet, due to a known issue in agama
  base images, but that will be changed.
* Wed Feb 19 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.5
  Suport architecture specific meta data
* Mon Feb 10 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.4
  support source and debug settings per flavor
  generate sha256 files for install.iso
* Thu Feb  6 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.3
  Adding skip_updateinfos build option to pass issue #14
* Thu Jan 30 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.2
  Handle baseisos like meta packages
  This means we don't expect them deployed in the build host system
  anymore. Instead we search for them in the given repositories for
  the product and unpack the containment rpm.
  The wanted side effect of this is that products will get rebuild,
  when the baseiso has changed now.
* Wed Jan 29 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.1
  * use mksusecd instead of xorriso, fixes boot partition, requires root
* Tue Jan 28 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.0
  * New option to add generated rpm-md tree to a base image.
    Can be used to create an agama based offline installer image.
* Fri Jan 24 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.4.21
  * Use generate_sbom from OBS server instance if available
    (boo#1231141)
* Mon Sep 30 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.20
  * fix logic of installcheck fatality
* Wed Sep 25 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.19
  * Avoid hanging installcheck with large output
* Mon Sep 23 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.18
  * Fix product name in SPDX SBOM files (was hardcoded to ALP)
  * Some more progress lines for logfile
* Mon Sep  2 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.17
  * abort_on_empty_updateinfo option added
  * allow to drop directory tree after iso generation
  * allow to enable iso generation by flavor
* Mon Jul 22 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.16
  * Crash fixes on incomplete iso spec or PkgSet substraction
* Wed Jul 17 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.15
  * avoid double export of -debug packages when using "all" option
* Tue Jul 16 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.14
  * added option to run installcheck
    => new dependency to libsolv-tools therefore
* Thu Jul 11 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.13
  * crash fix for "all available packages" option
* Mon Jul  8 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.12
  * fixed susedata generation (only a single language translation was generated)
  * Added option to include all available packages
* Wed Jun 26 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.11
  * canonized filenames (get rid of ::import prefixes)
* Wed Jun 26 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.10
  * support building on 15.6, using python311 stack (added sle-15-defaults.patch)
  * changing createrepo defaults for SLE 15 only
  * crash fix on incomplete generated groups by pkglistgen
* Wed Jun 26 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.9
  * Introduce "extension" product-type as alias for "module"
    Technical the same, but handled different in user accounting
  * fix for building without debug or source media
* Fri May 24 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.8
  * Support export of slsa.provenance files
  * Allow to override product directory per flavor
* Fri May 17 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.7
  * Support aborting on embargo updates in future
  * Clean updateinfo.xml from OBS internal elements
  * Add tagmedia for iso files to support checkmedia command
* Fri May 17 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.6
  * fixing signature creation for -Source and -Debug media
  * added option to allow to specify an updateinfo id prefix
* Thu May 16 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.5
  * generate .sha256 files for .iso files
* Thu Apr 11 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.4
  * supports also schema version 0.2 now
  * supports specifing add-on media product builds (versus OS)
  * supports overwriting package (from) information in updatinfo
* Wed Mar 27 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.3
  * Allow product builds without meta packages
  * improve disk-usage in susedata output
* Fri Mar  8 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.2
  * generate also diskusage data now (done by mls)
  * code cleanup
- add missing dependency to python-zstandard
* Thu Mar  7 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.1
  * write translations of package descriptions
* Wed Mar  6 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.0
  Replacement of susedata tool, first part
  - Add supportstatus
  - Add gpg trusted keys
  - switch to SHA512 checksum
  Missing:
  - diskusage data
  - package translations
* Fri Feb 23 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.4
  - support basic iso generation, not for bootable images yet
* Tue Feb  6 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.3
  - fixes incorrect data inside of repomd.xml
* Mon Feb  5 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.2
  * crash fixes
* Thu Jan 11 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.1
  * Supporting new 0.1 schema with extended functionality
  * signature handling fix
  * refactoring and code cleanup and documentation updates
* Tue Dec  5 2023 Adrian Schröter <adrian@suse.de>
- update to version 0.2
  * Support .report file generation
* Mon Dec  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Set service to manual run: server side execution not permitted in
  products.
- Do not use python-single-spec magic, but use python3 directly
  (the main python version).
* Mon Dec  4 2023 Adrian Schröter <adrian@suse.de>
- roll version 0.1
  Kind of a beta version for ALP based products.
* Wed Nov 15 2023 Adrian Schröter <adrian@suse.de>
- initial package
